==> nextcloud-app-mail-4.1.0-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/ia.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Importante",
    "Work" : "Travalio",
    "Personal" : "Personal",
    "Later" : "Depost",
    "Mail" : "Posta",
    "Name" : "Nomine",
    "Password" : "Contrasigno",
    "None" : "Nulle",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "SMTP Password" : "Contrasigno SMTP",
    "Connecting" : "Connectente",
    "Save" : "Salveguardar",
    "Connect" : "Connecter se",
    "Go back" : "Retornar",
    "Cancel" : "Cancellar",
    "General" : "General",
    "Keyboard shortcuts" : "Combinationes de claves",
    "Delete" : "Deler",
    "Search" : "Cercar",
    "Send" : "Inviar",
    "Refresh" : "Refrescar",
    "Choose a file to add as attachment" : "Selectiona un file pro adder como attachamento",
    "Confirm" : "Confirmar",
    "Favorite" : "Favorite",
    "Back" : "Retro",
    "Description" : "Description",
    "Create" : "Crear",
    "Select" : "Selectionar",
    "Comment" : "Commentario",
    "Accept" : "Acceptar",
    "Decline" : "Refusar",
    "Other" : "Altere",
    "Choose a folder to store the attachment in" : "Selectiona un dossier pro salveguardar le attachamento",
    "Unnamed" : "Non nominate",
    "Move" : "Mover",
    "Quota" : "Quota",
    "Saving" : "Salveguardante",
    "Remove account" : "Remover conto",
    "Rename" : "Renominar",
    "Sending …" : "Inviante ...",
    "Reply" : "Responder",
    "Add" : "Adder",
    "Close" : "Clauder",
    "Date" : "Date",
    "Tags" : "Etiquettas",
    "Custom" : "Personalisate",
    "Actions" : "Actiones",
    "Priority" : "Prioritate",
    "Reset" : "Re-fixar",
    "User" : "User",
    "Host" : "Hospite",
    "Port" : "Porto",
    "Valid until" : "Valide usque",
    "All" : "Tote",
    "Favorites" : "Favoritos",
    "All inboxes" : "Tote cassas de entrata",
    "Could not load {tag}{name}{endtag}" : "Impossibile cargar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Un problema occurreva durante le carga de {tag}{name}{endtag}"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-5.1.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/ia.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Importante",
    "Work" : "Travalio",
    "Personal" : "Personal",
    "Later" : "Depost",
    "Mail" : "Posta",
    "Connecting" : "Connectente",
    "Save" : "Salveguardar",
    "Connect" : "Connecter se",
    "Name" : "Nomine",
    "Password" : "Contrasigno",
    "None" : "Nulle",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "SMTP Password" : "Contrasigno SMTP",
    "Go back" : "Retornar",
    "Cancel" : "Cancellar",
    "General" : "General",
    "Keyboard shortcuts" : "Combinationes de claves",
    "Delete" : "Deler",
    "Search" : "Cercar",
    "Send" : "Inviar",
    "Refresh" : "Refrescar",
    "Choose a file to add as attachment" : "Selectiona un file pro adder como attachamento",
    "Confirm" : "Confirmar",
    "Favorite" : "Favorite",
    "Back" : "Retro",
    "Description" : "Description",
    "Create" : "Crear",
    "Select" : "Selectionar",
    "Comment" : "Commentario",
    "Accept" : "Acceptar",
    "Decline" : "Refusar",
    "Other" : "Altere",
    "Unnamed" : "Non nominate",
    "Choose a folder to store the attachment in" : "Selectiona un dossier pro salveguardar le attachamento",
    "Move" : "Mover",
    "Remove account" : "Remover conto",
    "Quota" : "Quota",
    "Saving" : "Salveguardante",
    "Rename" : "Renominar",
    "Reply" : "Responder",
    "Add" : "Adder",
    "Close" : "Clauder",
    "Date" : "Date",
    "Tags" : "Etiquettas",
    "Custom" : "Personalisate",
    "Actions" : "Actiones",
    "Priority" : "Prioritate",
    "Reset" : "Re-fixar",
    "User" : "User",
    "Host" : "Hospite",
    "Port" : "Porto",
    "Valid until" : "Valide usque",
    "All" : "Tote",
    "Favorites" : "Favoritos",
    "All inboxes" : "Tote cassas de entrata",
    "Could not load {tag}{name}{endtag}" : "Impossibile cargar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Un problema occurreva durante le carga de {tag}{name}{endtag}",
    "Sending …" : "Inviante ..."
},
"nplurals=2; plural=(n != 1);");
